@@ -591,15 +591,8 @@ def coshifta(xT, xP, refW=np.array([0]), n=np.array([1, 2, 3]), options=np.array
 
             if Filling == -np.inf:
             
-                print xP
-                print np.tile(xP[:, :1], (1., n)
-                print cat(1, np.tile(xP[:, :1], (1., n) )
-            
                 xtemp = cat(1, np.tile(xP[:, :1], (1., n)),
                             xP, np.tile(xP[:, -1:, ], (1., n)))
-
-                
-
                 # xtemp=np.array([xP[:,np.ones(1,n)],xP,xP[:,(mP[0,np.ones(1,n)]-1)]])
                 # #.reshape(1,-1)
 
